const express = require('express');

const schoolApp = express.Router();

const libs = `${process.cwd()}/libs`;

const squel = require('squel');

const query = require(`${libs}/middlewares/query`);

const response = require(`${libs}/middlewares/response`);

const ReqQueryFields = require(`${libs}/middlewares/reqQueryFields`);

let rqf = new ReqQueryFields();

rqf.addField({
    name: 'filter',
    field: false,
    where: true
}).addValue({
    name: 'id',
    table: 'escola',
    tableField: 'cod_entidade',
    where: {
        relation: '=',
        type: 'integer',
        field: 'cod_entidade'
    }
}).addValue({
    name: 'city',
    table: 'municipio',
    tableField: 'nome',
    resultField: 'city_name',
    where: {
        relation: '=',
        type: 'integer',
        field: 'fk_municipio_id',
        table: 'escola'
    },
    join: {
        primary: 'pk_cod_ibge',
        foreign: 'fk_municipio_id',
        foreignTable: 'escola'
    }
}).addValue({
    name: 'state',
    table: 'estado',
    tableField: 'nome',
    resultField: 'state_name',
    where: {
        relation: '=',
        type: 'integer',
        field: 'fk_estado_id',
        table: 'escola'
    },
    join: {
        primary: 'pk_estado_id',
        foreign: 'fk_estado_id',
        foreignTable: 'escola'
    }
});

schoolApp.get('/', rqf.parse(), rqf.build(), (req, res, next) => {
    console.log(req.filter);
    if(typeof req.filter === 'undefined' || Object.keys(req.filter).length === 0) {
        res.status(400);
        next({
            status: 400,
            message: 'Wrong/No filter specified'
        });
    }
    req.sql.from('escola')
        .field('escola.cod_entidade')
        .field('escola.ano_censo', 'year')
        .field('escola.fk_estado_id')
        .field('escola.fk_municipio_id');
    next();
}, query, response('school'));

module.exports = schoolApp;
